package cn.com.infosec.asn1.tsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;

public class Accuracy extends ASN1Encodable {
   protected static final int MIN_MILLIS = 1;
   protected static final int MAX_MILLIS = 999;
   protected static final int MIN_MICROS = 1;
   protected static final int MAX_MICROS = 999;
   DERInteger seconds;
   DERInteger millis;
   DERInteger micros;

   protected Accuracy() {
   }

   public Accuracy(DERInteger seconds, DERInteger millis, DERInteger micros) {
      this.seconds = seconds;
      if (millis == null || millis.getValue().intValue() >= 1 && millis.getValue().intValue() <= 999) {
         this.millis = millis;
         if (micros == null || micros.getValue().intValue() >= 1 && micros.getValue().intValue() <= 999) {
            this.micros = micros;
         } else {
            throw new IllegalArgumentException("Invalid micros field : not in (1..999)");
         }
      } else {
         throw new IllegalArgumentException("Invalid millis field : not in (1..999)");
      }
   }

   public Accuracy(ASN1Sequence seq) {
      this.seconds = null;
      this.millis = null;
      this.micros = null;

      for(int var2 = 0; var2 < seq.size(); ++var2) {
         if (seq.getObjectAt(var2) instanceof DERInteger) {
            this.seconds = (DERInteger)seq.getObjectAt(var2);
         } else if (seq.getObjectAt(var2) instanceof DERTaggedObject) {
            DERTaggedObject var3;
            int var4;
            DERInteger var5;
            if ((var4 = (var3 = (DERTaggedObject)seq.getObjectAt(var2)).getTagNo()) != 0) {
               if (var4 != 1) {
                  throw new IllegalArgumentException("Invalig tag number");
               }

               this.micros = var5 = DERInteger.getInstance(var3, false);
               if (var5.getValue().intValue() < 1 || this.micros.getValue().intValue() > 999) {
                  throw new IllegalArgumentException("Invalid micros field : not in (1..999).");
               }
            } else {
               this.millis = var5 = DERInteger.getInstance(var3, false);
               if (var5.getValue().intValue() < 1 || this.millis.getValue().intValue() > 999) {
                  throw new IllegalArgumentException("Invalid millis field : not in (1..999).");
               }
            }
         }
      }

   }

   public static Accuracy getInstance(Object o) {
      if (o != null && !(o instanceof Accuracy)) {
         if (o instanceof ASN1Sequence) {
            return new Accuracy((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("Unknown object in 'Accuracy' factory : " + o.getClass().getName() + ".");
         }
      } else {
         return (Accuracy)o;
      }
   }

   public DERInteger getSeconds() {
      return this.seconds;
   }

   public DERInteger getMillis() {
      return this.millis;
   }

   public DERInteger getMicros() {
      return this.micros;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERInteger var2;
      if ((var2 = this.seconds) != null) {
         var1.add(var2);
      }

      if ((var2 = this.millis) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      DERInteger var4;
      if ((var4 = this.micros) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(false, 1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
